## Description

<!-- Provide a clear and concise description of the changes in this PR -->

## Related Issue

Fixes #<!-- issue number -->

## Type of Change

<!-- Mark the relevant option with an 'x' -->

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring (no functional changes)
- [ ] Performance improvement
- [ ] Test improvements

## Changes Made

<!-- List the specific changes made in this PR -->

-
-
-

## Testing

<!-- Describe the testing you've done -->

- [ ] All existing tests pass (`uv run pytest`)
- [ ] New tests added for new functionality
- [ ] Tests achieve 100% coverage
- [ ] Manual testing performed

### Test Coverage

<!-- Include coverage report snippet if applicable -->

```
# Paste relevant coverage output here
```

## Checklist

- [ ] Code follows the project's style guidelines (ruff, isort)
- [ ] Pre-commit hooks pass (`uv run pre-commit run --all-files`)
- [ ] Documentation updated (README, CLAUDE.md, docstrings, CHANGELOG.md)
- [ ] Type annotations added where applicable
- [ ] Commit messages follow conventional commit format
- [ ] No sensitive information (API keys, tokens) included

## Screenshots (if applicable)

<!-- Add screenshots to help explain your changes -->

## Additional Notes

<!-- Any additional information that reviewers should know -->
